==> elasticloadbalancingv2-1.15.0.DEVPREVIEW-sources.jar: software/amazon/awscdk/services/elasticloadbalancingv2/TargetGroupAttributes.java <==
package software.amazon.awscdk.services.elasticloadbalancingv2;

/**
 * Properties to reference an existing target group.
 */
@javax.annotation.Generated(value = "jsii-pacmak/0.19.0 (build 7c562bc)", date = "2019-10-28T12:26:31.934Z")
@software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
public interface TargetGroupAttributes extends software.amazon.jsii.JsiiSerializable {

    /**
     * ARN of the target group.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    java.lang.String getTargetGroupArn();

    /**
     * Port target group is listening on.
     * 
     * @deprecated - This property is unused and the wrong type. No need to use it.
     */
    @Deprecated
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Deprecated)
    java.lang.String getDefaultPort();

    /**
     * A Token representing the list of ARNs for the load balancer routing to this target group.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    java.lang.String getLoadBalancerArns();

    /**
     * @return a {@link Builder} of {@link TargetGroupAttributes}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    static Builder builder() {
        return new Builder();
    }
    /**
     * A builder for {@link TargetGroupAttributes}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public static final class Builder {
        private java.lang.String targetGroupArn;
        private java.lang.String defaultPort;
        private java.lang.String loadBalancerArns;

        /**
         * Sets the value of TargetGroupArn
         * @param targetGroupArn ARN of the target group. This parameter is required.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder targetGroupArn(java.lang.String targetGroupArn) {
            this.targetGroupArn = targetGroupArn;
            return this;
        }

        /**
         * Sets the value of DefaultPort
         * @param defaultPort Port target group is listening on.
         * @return {@code this}
         * @deprecated - This property is unused and the wrong type. No need to use it.
         */
        @Deprecated
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Deprecated)
        public Builder defaultPort(java.lang.String defaultPort) {
            this.defaultPort = defaultPort;
            return this;
        }

        /**
         * Sets the value of LoadBalancerArns
         * @param loadBalancerArns A Token representing the list of ARNs for the load balancer routing to this target group.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder loadBalancerArns(java.lang.String loadBalancerArns) {
            this.loadBalancerArns = loadBalancerArns;
            return this;
        }

        /**
         * Builds the configured instance.
         * @return a new instance of {@link TargetGroupAttributes}
         * @throws NullPointerException if any required attribute was not provided
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public TargetGroupAttributes build() {
            return new Jsii$Proxy(targetGroupArn, defaultPort, loadBalancerArns);
        }
    }

    /**
     * An implementation for {@link TargetGroupAttributes}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    final class Jsii$Proxy extends software.amazon.jsii.JsiiObject implements TargetGroupAttributes {
        private final java.lang.String targetGroupArn;
        private final java.lang.String defaultPort;
        private final java.lang.String loadBalancerArns;

        /**
         * Constructor that initializes the object based on values retrieved from the JsiiObject.
         * @param objRef Reference to the JSII managed object.
         */
        protected Jsii$Proxy(final software.amazon.jsii.JsiiObjectRef objRef) {
            super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
            this.setObjRef(objRef);
            this.targetGroupArn = this.jsiiGet("targetGroupArn", java.lang.String.class);
            this.defaultPort = this.jsiiGet("defaultPort", java.lang.String.class);
            this.loadBalancerArns = this.jsiiGet("loadBalancerArns", java.lang.String.class);
        }

        /**
         * Constructor that initializes the object based on literal property values passed by the {@link Builder}.
         */
        private Jsii$Proxy(java.lang.String targetGroupArn, java.lang.String defaultPort, java.lang.String loadBalancerArns) {
            super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
            this.targetGroupArn = java.util.Objects.requireNonNull(targetGroupArn, "targetGroupArn is required");
            this.defaultPort = defaultPort;
            this.loadBalancerArns = loadBalancerArns;
        }

        @Override
        public java.lang.String getTargetGroupArn() {
            return this.targetGroupArn;
        }

        @Override
        public java.lang.String getDefaultPort() {
            return this.defaultPort;
        }

        @Override
        public java.lang.String getLoadBalancerArns() {
            return this.loadBalancerArns;
        }

        @Override
        public com.fasterxml.jackson.databind.JsonNode $jsii$toJson() {
            com.fasterxml.jackson.databind.ObjectMapper om = software.amazon.jsii.JsiiObjectMapper.INSTANCE;
            com.fasterxml.jackson.databind.node.ObjectNode obj = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            obj.set("targetGroupArn", om.valueToTree(this.getTargetGroupArn()));
            if (this.getDefaultPort() != null) {
                obj.set("defaultPort", om.valueToTree(this.getDefaultPort()));
            }
            if (this.getLoadBalancerArns() != null) {
                obj.set("loadBalancerArns", om.valueToTree(this.getLoadBalancerArns()));
            }
            return obj;
        }

        @Override
        public boolean equals(Object o) {
            if (this == o) return true;
            if (o == null || getClass() != o.getClass()) return false;

            TargetGroupAttributes.Jsii$Proxy that = (TargetGroupAttributes.Jsii$Proxy) o;

            if (!targetGroupArn.equals(that.targetGroupArn)) return false;
            if (this.defaultPort != null ? !this.defaultPort.equals(that.defaultPort) : that.defaultPort != null) return false;
            return this.loadBalancerArns != null ? this.loadBalancerArns.equals(that.loadBalancerArns) : that.loadBalancerArns == null;
        }

        @Override
        public int hashCode() {
            int result = this.targetGroupArn.hashCode();
            result = 31 * result + (this.defaultPort != null ? this.defaultPort.hashCode() : 0);
            result = 31 * result + (this.loadBalancerArns != null ? this.loadBalancerArns.hashCode() : 0);
            return result;
        }
    }
}

==> elasticloadbalancingv2-1.16.1.DEVPREVIEW-sources.jar: software/amazon/awscdk/services/elasticloadbalancingv2/TargetGroupAttributes.java <==
package software.amazon.awscdk.services.elasticloadbalancingv2;

/**
 * Properties to reference an existing target group.
 */
@javax.annotation.Generated(value = "jsii-pacmak/0.20.3 (build 26aa77c)", date = "2019-11-12T00:10:05.423Z")
@software.amazon.jsii.Jsii(module = software.amazon.awscdk.services.elasticloadbalancingv2.$Module.class, fqn = "@aws-cdk/aws-elasticloadbalancingv2.TargetGroupAttributes")
@software.amazon.jsii.Jsii.Proxy(TargetGroupAttributes.Jsii$Proxy.class)
@software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
public interface TargetGroupAttributes extends software.amazon.jsii.JsiiSerializable {

    /**
     * ARN of the target group.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    java.lang.String getTargetGroupArn();

    /**
     * Port target group is listening on.
     * 
     * @deprecated - This property is unused and the wrong type. No need to use it.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Deprecated)
    @Deprecated
    default java.lang.String getDefaultPort() {
        return null;
    }

    /**
     * A Token representing the list of ARNs for the load balancer routing to this target group.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    default java.lang.String getLoadBalancerArns() {
        return null;
    }

    /**
     * @return a {@link Builder} of {@link TargetGroupAttributes}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    static Builder builder() {
        return new Builder();
    }
    /**
     * A builder for {@link TargetGroupAttributes}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public static final class Builder {
        private java.lang.String targetGroupArn;
        private java.lang.String defaultPort;
        private java.lang.String loadBalancerArns;

        /**
         * Sets the value of TargetGroupArn
         * @param targetGroupArn ARN of the target group. This parameter is required.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder targetGroupArn(java.lang.String targetGroupArn) {
            this.targetGroupArn = targetGroupArn;
            return this;
        }

        /**
         * Sets the value of DefaultPort
         * @param defaultPort Port target group is listening on.
         * @return {@code this}
         * @deprecated - This property is unused and the wrong type. No need to use it.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Deprecated)
        @Deprecated
        public Builder defaultPort(java.lang.String defaultPort) {
            this.defaultPort = defaultPort;
            return this;
        }

        /**
         * Sets the value of LoadBalancerArns
         * @param loadBalancerArns A Token representing the list of ARNs for the load balancer routing to this target group.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder loadBalancerArns(java.lang.String loadBalancerArns) {
            this.loadBalancerArns = loadBalancerArns;
            return this;
        }

        /**
         * Builds the configured instance.
         * @return a new instance of {@link TargetGroupAttributes}
         * @throws NullPointerException if any required attribute was not provided
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public TargetGroupAttributes build() {
            return new Jsii$Proxy(targetGroupArn, defaultPort, loadBalancerArns);
        }
    }

    /**
     * An implementation for {@link TargetGroupAttributes}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    final class Jsii$Proxy extends software.amazon.jsii.JsiiObject implements TargetGroupAttributes {
        private final java.lang.String targetGroupArn;
        private final java.lang.String defaultPort;
        private final java.lang.String loadBalancerArns;

        /**
         * Constructor that initializes the object based on values retrieved from the JsiiObject.
         * @param objRef Reference to the JSII managed object.
         */
        protected Jsii$Proxy(final software.amazon.jsii.JsiiObjectRef objRef) {
            super(objRef);
            this.targetGroupArn = this.jsiiGet("targetGroupArn", java.lang.String.class);
            this.defaultPort = this.jsiiGet("defaultPort", java.lang.String.class);
            this.loadBalancerArns = this.jsiiGet("loadBalancerArns", java.lang.String.class);
        }

        /**
         * Constructor that initializes the object based on literal property values passed by the {@link Builder}.
         */
        private Jsii$Proxy(final java.lang.String targetGroupArn, final java.lang.String defaultPort, final java.lang.String loadBalancerArns) {
            super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
            this.targetGroupArn = java.util.Objects.requireNonNull(targetGroupArn, "targetGroupArn is required");
            this.defaultPort = defaultPort;
            this.loadBalancerArns = loadBalancerArns;
        }

        @Override
        public java.lang.String getTargetGroupArn() {
            return this.targetGroupArn;
        }

        @Override
        public java.lang.String getDefaultPort() {
            return this.defaultPort;
        }

        @Override
        public java.lang.String getLoadBalancerArns() {
            return this.loadBalancerArns;
        }

        @Override
        public com.fasterxml.jackson.databind.JsonNode $jsii$toJson() {
            final com.fasterxml.jackson.databind.ObjectMapper om = software.amazon.jsii.JsiiObjectMapper.INSTANCE;
            final com.fasterxml.jackson.databind.node.ObjectNode data = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();

            data.set("targetGroupArn", om.valueToTree(this.getTargetGroupArn()));
            if (this.getDefaultPort() != null) {
                data.set("defaultPort", om.valueToTree(this.getDefaultPort()));
            }
            if (this.getLoadBalancerArns() != null) {
                data.set("loadBalancerArns", om.valueToTree(this.getLoadBalancerArns()));
            }

            final com.fasterxml.jackson.databind.node.ObjectNode struct = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            struct.set("fqn", om.valueToTree("@aws-cdk/aws-elasticloadbalancingv2.TargetGroupAttributes"));
            struct.set("data", data);

            final com.fasterxml.jackson.databind.node.ObjectNode obj = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            obj.set("$jsii.struct", struct);

            return obj;
        }

        @Override
        public boolean equals(Object o) {
            if (this == o) return true;
            if (o == null || getClass() != o.getClass()) return false;

            TargetGroupAttributes.Jsii$Proxy that = (TargetGroupAttributes.Jsii$Proxy) o;

            if (!targetGroupArn.equals(that.targetGroupArn)) return false;
            if (this.defaultPort != null ? !this.defaultPort.equals(that.defaultPort) : that.defaultPort != null) return false;
            return this.loadBalancerArns != null ? this.loadBalancerArns.equals(that.loadBalancerArns) : that.loadBalancerArns == null;
        }

        @Override
        public int hashCode() {
            int result = this.targetGroupArn.hashCode();
            result = 31 * result + (this.defaultPort != null ? this.defaultPort.hashCode() : 0);
            result = 31 * result + (this.loadBalancerArns != null ? this.loadBalancerArns.hashCode() : 0);
            return result;
        }
    }
}
